#!/bin/ksh
#BEGINPROLOGUE*********************************************************#
#                                                                      #
# COPYRIGHT:                                                           #
# ----------                                                           #
# Digital Library Version 2 - 5765-C86.                                #
# VisualInfo Version 2 Release 3.0 - 5697-250.                         #
# (C) Copyright IBM Corp., 1994,1997.  All Rights Reserved.            #
#                                                                      #
# US Government Users Restricted Rights                                #
# Use, duplication or disclosure restricted by GSA ADP Schedule        #
# Contract with IBM Corp.  Licensed Materials - Property of IBM        #
#                                                                      #
#ENDPROLOGUE***********************************************************#
#***********************************************************************
# Program name  : frnxupdate.sh                                        *
#                                                                      *
#                                                                      *
# Description   : Apply the PTF fixes                                  *
# Change History:                                                      *
#  041599 f12635 llee Check installable images from input before update
#  110298 f10816 len Check JDK116 for SDK                              *
#  080698 f9871 lud Check JDK114 for SDK                               *
#  072498 f9628 lud Disable mms for CSD231                             *
#***********************************************************************
# Display copyright statement and please wait message
#/usr/bin/cat ./copyright
#
# Get the current directory where the installation images are
#
if [[ $1 != "" ]] then
   FrnxImgDir=$1
else
   FrnxImgDir=`pwd`
fi
#
# Make sure "root" is the user ID
#
user=`whoami`
if [[ $user != "root" ]]; then
   echo "\nThe AIX 'root' user ID is required."
   echo "The current user ID, $user, can not perform the AIX installation function.\n"
   exit 1
fi # end of if current user is not root

if [[ -a /tmp/frnxinst$$.log ]] then
    /usr/bin/rm /tmp/frnxinst$$.log
fi
#
# initialize variables, str points to frnxupdate.data which contains the
# compid, fileset name, and component selectable component description in
# /usr/lpp/frn/bin/$LANG/frnxinst.txt file
#
str="cmn tkt wm sdk dpb libd libo objd objo imsb imss imsc txss txsc txsd ndt"
msg1="No component will be updated"
msg2="\nAbove components exist on your machine.\nThey will be updated if fix are available on installation media.\nPress Enter to update. Press other key to quit."
src=$FrnxImgDir/frnxupdate.data
##src=/tmp/csd211/frnxupdate.data
#
#  s etup component fileset name in xfs
# setup component name in xdes
#
function getcomp
{
  x=`grep $1 $src | cut -f2 -d"="`
  xfs=`echo $x | cut -f1 -d";"`
  xdes=`echo $x | cut -f2 -d";"`
}
#
# check component exists on local system
# display only the selectable ones
#
function checkcomp
{
 lslpp -l $1* > /dev/null 2>&1
 if [[ $? -eq 0 ]] then
   comp=$comp$i" "
   if [[ -n $xdes ]] then
     echo $xdes
   fi
   case $i in
       libd)
            frnbind=$frnbind" Library Server"
            ;;
       objd)
            frnbind=$frnbind" Object Server"
            ;;
   esac
 fi
}
#
# invoke installp to update files, will bring in the prereq if needed
#
function update
{
  #check if fix exists on installation media
  installp -L -d $FrnxImgDir | grep $xfs > /dev/null
  if [[ $? -eq 0 ]] 
  then 
      echo "Updating " $xfs
      installp -ac  -X -V2 -d $FrnxImgDir $xfs >> /tmp/frnxinst$$.log 2>&1
      if [[ $? -eq 0 ]] then
          echo $xfs "has been updated successfully"
      else
          echo "\nError occurred while updating " $xfs
          echo "Check "/tmp/frnxinst$$.log" for detail information."
      fi
  fi
}
#
# go through components and check if on the local system, stored in comp
#
comp=""
frncomp=""
echo "\n"
for i in $str
do
  getcomp $i
  checkcomp $xfs
done
#echo ${comp:-$msg1}
#
# if no component exists on the local system, exit
#
if [[ -z $comp ]] then
   echo $msg1
   exit
#
# if component exists on the local system, ready to update
#
else
   echo $msg2
   read x
   if [[ -n $x ]] then
   exit
   fi
fi
#
# update the components in comp string
#

for i in $comp
do
  getcomp $i
  update $xfs
done
#
# display post update message
#
msg3="\n\nThe codes on your system have been updated."
msg6="\nYou need to upgrade JDK to 1.1.6 for Java OO/API"
echo $msg3

# f9871 (superseded by f10816)
x=`lslpp -l frn.sdk > /dev/null 2>&1`
if [[ $? -eq 0 ]] then
  y=`lslpp -qcl Java.rte.bin | cut -d":" -f3`
  x="1.1.6.0"

  # Derive required ver/rel/mod/fix numbers
  eval $(echo $x | awk -F. '{printf "xVer=%d; xRelease=%d; xMod=%d; xFix=%d", $1, $2, $3, $4}')

  # Derive current system's ver/rel/mod/fix numbers
  eval $(echo $y | awk -F. '{printf "yVer=%d; yRelease=%d; yMod=%d; yFix=%d", $1, $2, $3, $4}')

  if (( ( $xVer >  $yVer ) ||
        ( $xVer == $yVer && $xRelease >  $yRelease ) ||
        ( $xVer == $yVer && $xRelease == $yRelease && $xMod >  $yMod ) ||
        ( $xVer == $yVer && $xRelease == $yRelease && $xMod == $yMod && $xFix > $yFix ) )) then 
     echo $msg6
  fi
fi

return 0
